@@ -1,3 +1,5 @@
+from functools import partial
+
 from content_editor.models import Type
 from django import forms
 from django.core import validators
@@ -28,7 +30,7 @@ class FormType(Type):
 
     def __init__(self, **kwargs):
         kwargs.setdefault("form_class", forms.Form)
-        kwargs.setdefault("validate", lambda form: [])
+        kwargs.setdefault("validate", lambda configured_form: [])
         super().__init__(**kwargs)
 
     form_class = ImportDescriptor()
@@ -64,7 +66,7 @@ class ConfiguredForm(models.Model):
             field.choices = [(row["key"], row["label"]) for row in sender.FORMS]
 
             types = {type.key: type for type in sender.FORMS}
-            sender.type = property(lambda self: import_if_string(types[self.form]))
+            sender.type = property(lambda self: import_if_string(types.get(self.form)))
 
     def get_formfields_union(self, *, plugins, values=["name"]):
         qs = None
@@ -77,7 +79,7 @@ class ConfiguredForm(models.Model):
             if qs is None:
                 qs = plugin_qs
             else:
-                qs = qs.union(plugin_qs)
+                qs = qs.union(plugin_qs, all=True)
         return qs
 
 
@@ -130,20 +132,18 @@ class FormField(models.Model):
     def __str__(self):
         return self.label
 
-    def get_fields(self, *, form_class, initial=None, **kwargs):
+    def get_fields(self, *, form_class, **kwargs):
         kwargs.setdefault("label", self.label)
         kwargs.setdefault("required", self.is_required)
         kwargs.setdefault("help_text", self.help_text)
         return {self.name: form_class(**kwargs)}
 
     def get_loaders(self):
-        return [
-            lambda data: {
-                "label": self.label,
-                "name": self.name,
-                "value": data.get(self.name),
-            }
-        ]
+        return [partial(simple_loader, label=self.label, name=self.name)]
+
+
+def simple_loader(data, *, label, name):
+    return {"label": label, "name": name, "value": data.get(name)}
 
 
 class SimpleFieldBase(FormField):
@@ -229,14 +229,15 @@ class SimpleFieldBase(FormField):
 
         return [_choice(value) for value in self.choices.splitlines() if value]
 
-    def get_fields(self, *, initial=None, **kwargs):
-        T = self.Type
+    def get_initial(self):
+        if not self.default_value:
+            return {}
+        if self.choices:
+            return {self.name: slugify(self.default_value)}
+        return {self.name: self.default_value}
 
-        if self.default_value and initial is not None:
-            if self.choices:
-                initial.setdefault(self.name, slugify(self.default_value))
-            else:
-                initial.setdefault(self.name, self.default_value)
+    def get_fields(self, **kwargs):
+        T = self.Type
 
         if self.type == T.TEXT:
             return super().get_fields(
